import { Project, Task } from "projen";
import { JavaProject, JavaProjectOptions } from "projen/lib/java";
import { PythonProject } from "projen/lib/python";
import { NxWorkspace } from "../../components/nx-workspace";
import { Nx } from "../../nx-types";
/**
 * Configuration options for the NxMonorepoJavaProject.
 */
export interface NxMonorepoJavaOptions extends JavaProjectOptions {
    readonly defaultReleaseBranch?: string;
}
/**
 * This project type will bootstrap a NX based monorepo with support for polygot
 * builds, build caching, dependency graph visualization and much more.
 *
 * @pjid nx-monorepo-java
 */
export declare class NxMonorepoJavaProject extends JavaProject {
    readonly nx: NxWorkspace;
    constructor(options: NxMonorepoJavaOptions);
    /**
     * Helper to format `npx nx run-many ...` style command execution in package manager.
     * @param options
     */
    execNxRunManyCommand(options: Nx.RunManyOptions): string;
    /**
     * Helper to format `npx nx run-many ...` style command
     * @param options
     */
    composeNxRunManyCommand(options: Nx.RunManyOptions): string[];
    /**
     * Add project task that executes `npx nx run-many ...` style command.
     */
    addNxRunManyTask(name: string, options: Nx.RunManyOptions): Task;
    /**
     * Create an implicit dependency between two Projects. This is typically
     * used in polygot repos where a Typescript project wants a build dependency
     * on a Python project as an example.
     *
     * @param dependent project you want to have the dependency.
     * @param dependee project you wish to depend on.
     * @throws error if this is called on a dependent which does not have a NXProject component attached.
     */
    addImplicitDependency(dependent: Project, dependee: Project | string): void;
    /**
     * Adds a dependency between two Java Projects in the monorepo.
     * @param dependent project you want to have the dependency
     * @param dependee project you wish to depend on
     */
    addJavaDependency(dependent: JavaProject, dependee: JavaProject): void;
    /**
     * Adds a dependency between two Python Projects in the monorepo. The dependent must have Poetry enabled.
     * @param dependent project you want to have the dependency (must be a Poetry Python Project)
     * @param dependee project you wish to depend on
     * @throws error if the dependent does not have Poetry enabled
     */
    addPythonPoetryDependency(dependent: PythonProject, dependee: PythonProject): void;
    /**
     * Ensures that all non-root projects have NxProject applied.
     * @internal
     */
    protected _ensureNxProjectGraph(): void;
    preSynthesize(): void;
    /**
     * @inheritDoc
     */
    synth(): void;
    /**
     * Configures the Java plugin on NX and ensures local nx dependencies are installed.
     */
    private setupJavaNx;
    /**
     * Ensures subprojects don't have a default task
     */
    private resetDefaultTask;
}
